@@ -2,36 +2,41 @@
 #'
 #' @import htmlwidgets
 #'
-#' @param token Mapbox Acess token. Use \code{set_token()} to use a global token
-#' @param data data to be used on the map
+#' @param token Mapbox Acess token. Use \code{set_token()} to set a global token.
+#' If left empty layers will still be plotted, but without a Mapbox map.
+#' @param data data to be used on the map. All coordinates are expected to be in
+#' Web Mercator Projection
 #' @param width the width of the map
 #' @param height the height of the map
 #' @param padding the padding of the map
 #' @param style the style of the map
 #' @param pitch the pitch angle of the map
 #' @param zoom zoom level of the map
-#' @param location vector of lon and lat coordinates (in that order)
+#' @param bearing bearing of the map between 0 and 360
+#' @param location unnamed vector of lon and lat coordinates (in that order)
 #'
 #' @export
 mapdeck <- function(
-	token = get_access_token(api = 'mapbox'),
 	data = NULL,
+	token = get_access_token( api = 'mapbox' ),
 	width = NULL,
 	height = NULL,
 	padding = 0,
 	style = 'mapbox://styles/mapbox/streets-v9',
 	pitch = 0,
 	zoom = 0,
-	location = c(0, 0)
+	bearing = 0,
+	location = c( 0, 0 )
 	) {
 
   # forward options using x
   x = list(
-    access_token = token
-    , style = style
-    , pitch = pitch
-    , zoom = zoom
-    , location = location
+    access_token = force( token )
+    , style = force( style )
+    , pitch = force( pitch )
+    , zoom = force( zoom )
+    , location = force( as.numeric( location ) )
+    , bearing = force( bearing )
   )
 
   # create widget
@@ -91,7 +96,8 @@ renderMapdeck <- function(expr, env = parent.frame(), quoted = FALSE) {
 #' @param map_id string containing the output ID of the map in a shiny application.
 #' @param session the Shiny session object to which the map belongs; usually the
 #' default value will suffice.
-#' @param data data to be used in the map. See the details section for \code{\link{mapdeck}}.
+#' @param data data to be used in the map. All coordinates are expected to be in
+#' Web Mercator Projection
 #' @param deferUntilFlush indicates whether actions performed against this
 #' instance should be carried out right away, or whether they should be held until
 #' after the next time all of the outputs are updated; defaults to TRUE.
@@ -134,22 +140,27 @@ mapdeck_update <- function(
 #' @export
 mapdeck_view <- function(
 	map,
-	location,
-	zoom = 6,
-	duration = 0,
+	location = NULL,
+	zoom = NULL,
+	pitch = NULL,
+	bearing = NULL,
+	duration = NULL,
 	transition = c("linear", "fly")
 	) {
 
 	transition <- match.arg(transition)
-	invoke_method(map, 'change_location', location, duration, transition, zoom)
+	invoke_method(
+		map, 'md_change_location', as.numeric( location ), zoom, pitch,
+		bearing, duration, transition
+		)
 }
 
 # Get Map Data
 #
 # extracts the data attribute from the map
 #
-# @param map a mapdeck_map object
+# @param map a mapdeck map object
 #
-get_map_data = function(map){
-	attr(map$x, "map_map_data", exact = TRUE)
+get_map_data = function( map ) {
+	attr( map$x, "mapdeck_data", exact = TRUE )
 }
