@@ -1,18 +1,22 @@
+#' @useDynLib mapdeck, .registration = TRUE
+#' @importFrom Rcpp sourceCpp
+NULL
+
 #' Pipe
 #'
 #' Uses the pipe operator (\code{\%>\%}) to chain statements. Useful for adding
-#' layers to a \code{google_map}
+#' layers to a \code{mapdeck} map
 #'
 #' @importFrom magrittr %>%
 #' @name %>%
 #' @rdname pipe
 #' @export
-#' @param lhs,rhs A google map and a layer to add to it
+#' @param lhs,rhs A mapdeck map and a layer to add to it
 #' @examples
 #' \donttest{
 #'
 #' key <- "your_api_key"
-#' mapdeck_map(key = key) %>%
+#' mapdeck(key = key) %>%
 #' add_scatterplot(
 #'   data = capitals
 #'   , lat = "lat"
